@@ -7,6 +7,7 @@ from dataclasses import dataclass
 class Scope(IntEnum):
     SINGLETON: int = 0
     TRANSIENT: int = 1
+    CONTEXT: int = 2
 
 
 @dataclass
@@ -16,3 +17,4 @@ class DependencyWrapper:
     annotations: Optional[Tuple[Tuple[str, Any]]] = None
     scope: int = Scope.TRANSIENT
     cache: Optional[Any] = None
+    type_arguments: Tuple = ()
